The ``FullRecorder`` class
##########################

.. autoclass:: pylife.stress.rainflow.FullRecorder
               :members:
               :undoc-members:
               :special-members: __init__
